@@ -19,18 +19,18 @@ impl<'a> Resolver<'a> {
     pub(crate) fn resolve(&self, import: CollectedImport) -> Option<&'a FilePath> {
         match import {
             CollectedImport::Import(import) => {
-                resolve_module(self.db, import).map(|module| module.file().path(self.db))
+                resolve_module(self.db, &import).map(|module| module.file().path(self.db))
             }
             CollectedImport::ImportFrom(import) => {
                 // Attempt to resolve the member (e.g., given `from foo import bar`, look for `foo.bar`).
                 let parent = import.parent();
 
-                resolve_module(self.db, import)
+                resolve_module(self.db, &import)
                     .map(|module| module.file().path(self.db))
                     .or_else(|| {
                         // Attempt to resolve the module (e.g., given `from foo import bar`, look for `foo`).
 
-                        resolve_module(self.db, parent?).map(|module| module.file().path(self.db))
+                        resolve_module(self.db, &parent?).map(|module| module.file().path(self.db))
                     })
             }
         }
