@@ -17,3 +17,11 @@ def f(*args: Unpack[other.Type]): pass
 def foo(*args: Unpack[int | str]) -> None: pass
 def foo(*args: Unpack[int and str]) -> None: pass
 def foo(*args: Unpack[int > str]) -> None: pass
+
+# We do not use the shorthand unpacking syntax in the following cases
+from typing import TypedDict
+class KwargsDict(TypedDict):
+    x: int
+    y: int
+
+def foo(name: str, /, **kwargs: Unpack[KwargsDict]) -> None: pass
