@@ -22,7 +22,7 @@ async def pass_3():  # OK: uses an async loop
 
 
 class Foo:
-    async def pass_4():  # OK: method of a class
+    async def pass_4(self):  # OK: method of a class
         pass
 
 
@@ -31,6 +31,10 @@ def foo():
         await bla
 
 
+async def pass_6():  # OK: just a stub
+    ...
+
+
 async def fail_1a():  # RUF029
     time.sleep(1)
 
@@ -58,10 +62,29 @@ async def fail_4a():  # RUF029: the /outer/ function does not await
 
 async def fail_4b():  # RUF029: the /outer/ function does not await
     class Foo:
-        async def foo():
+        async def foo(self):
             await bla
 
 
 def foo():
     async def fail_4c():  # RUF029: the /inner/ function does not await
         pass
+
+
+async def test():
+    return [check async for check in async_func()]
+
+
+async def test() -> str:
+    vals = [str(val) for val in await async_func(1)]
+    return ",".join(vals)
+
+
+from fastapi import FastAPI
+
+app = FastAPI()
+
+
+@app.post("/count")
+async def fastapi_route(): # Ok: FastApi routes can be async without actually using await
+    return 1
