@@ -1,6 +1,6 @@
 use ruff_diagnostics::{Diagnostic, Violation};
 use ruff_macros::{derive_message_formats, violation};
-use ruff_python_ast::{self as ast, Constant, Expr};
+use ruff_python_ast::{self as ast, Expr};
 use ruff_text_size::Ranged;
 
 use crate::checkers::ast::Checker;
@@ -43,7 +43,7 @@ pub struct SysVersionSlice3;
 impl Violation for SysVersionSlice3 {
     #[derive_message_formats]
     fn message(&self) -> String {
-        format!("`sys.version[:3]` referenced (python3.10), use `sys.version_info`")
+        "`sys.version[:3]` referenced (python3.10), use `sys.version_info`".to_string()
     }
 }
 
@@ -83,7 +83,7 @@ pub struct SysVersion2;
 impl Violation for SysVersion2 {
     #[derive_message_formats]
     fn message(&self) -> String {
-        format!("`sys.version[2]` referenced (python3.10), use `sys.version_info`")
+        "`sys.version[2]` referenced (python3.10), use `sys.version_info`".to_string()
     }
 }
 
@@ -93,7 +93,7 @@ impl Violation for SysVersion2 {
 /// ## Why is this bad?
 /// If the current major or minor version consists of multiple digits,
 /// `sys.version[0]` will select the first digit of the major version number
-/// only (e.g., `"3.10"` would evaluate to `"1"`). This is likely unintended,
+/// only (e.g., `"10.2"` would evaluate to `"1"`). This is likely unintended,
 /// and can lead to subtle bugs if the version string is used to test against a
 /// major version number.
 ///
@@ -123,7 +123,7 @@ pub struct SysVersion0;
 impl Violation for SysVersion0 {
     #[derive_message_formats]
     fn message(&self) -> String {
-        format!("`sys.version[0]` referenced (python10), use `sys.version_info`")
+        "`sys.version[0]` referenced (python10), use `sys.version_info`".to_string()
     }
 }
 
@@ -163,7 +163,7 @@ pub struct SysVersionSlice1;
 impl Violation for SysVersionSlice1 {
     #[derive_message_formats]
     fn message(&self) -> String {
-        format!("`sys.version[:1]` referenced (python10), use `sys.version_info`")
+        "`sys.version[:1]` referenced (python10), use `sys.version_info`".to_string()
     }
 }
 
@@ -177,8 +177,8 @@ pub(crate) fn subscript(checker: &mut Checker, value: &Expr, slice: &Expr) {
                 step: None,
                 range: _,
             }) => {
-                if let Expr::Constant(ast::ExprConstant {
-                    value: Constant::Int(i),
+                if let Expr::NumberLiteral(ast::ExprNumberLiteral {
+                    value: ast::Number::Int(i),
                     ..
                 }) = upper.as_ref()
                 {
@@ -194,8 +194,8 @@ pub(crate) fn subscript(checker: &mut Checker, value: &Expr, slice: &Expr) {
                 }
             }
 
-            Expr::Constant(ast::ExprConstant {
-                value: Constant::Int(i),
+            Expr::NumberLiteral(ast::ExprNumberLiteral {
+                value: ast::Number::Int(i),
                 ..
             }) => {
                 if *i == 2 && checker.enabled(Rule::SysVersion2) {
