@@ -19,15 +19,15 @@ use super::helpers;
 /// datetime objects. Since this can lead to errors, it is recommended to
 /// always use timezone-aware objects.
 ///
-/// `datetime.datetime.utcfromtimestamp()` returns a naive datetime object;
-/// instead, use `datetime.datetime.fromtimestamp(ts, tz=)` to return a
-/// timezone-aware object.
+/// `datetime.datetime.utcfromtimestamp()` returns a naive datetime
+/// object; instead, use `datetime.datetime.fromtimestamp(ts, tz=...)`
+/// to create a timezone-aware object.
 ///
 /// ## Example
 /// ```python
 /// import datetime
 ///
-/// datetime.datetime.utcfromtimestamp()
+/// datetime.datetime.utcfromtimestamp(946684800)
 /// ```
 ///
 /// Use instead:
@@ -37,7 +37,7 @@ use super::helpers;
 /// datetime.datetime.fromtimestamp(946684800, tz=datetime.timezone.utc)
 /// ```
 ///
-/// Or, for Python 3.11 and later:
+/// Or, on Python 3.11 and later:
 /// ```python
 /// import datetime
 ///
@@ -52,10 +52,11 @@ pub struct CallDatetimeUtcfromtimestamp;
 impl Violation for CallDatetimeUtcfromtimestamp {
     #[derive_message_formats]
     fn message(&self) -> String {
-        format!(
-            "The use of `datetime.datetime.utcfromtimestamp()` is not allowed, use \
-             `datetime.datetime.fromtimestamp(ts, tz=)` instead"
-        )
+        "`datetime.datetime.utcfromtimestamp()` used".to_string()
+    }
+
+    fn fix_title(&self) -> Option<String> {
+        Some("Use `datetime.datetime.fromtimestamp(ts, tz=...)` instead".to_string())
     }
 }
 
@@ -70,10 +71,10 @@ pub(crate) fn call_datetime_utcfromtimestamp(
 
     if !checker
         .semantic()
-        .resolve_call_path(func)
-        .is_some_and(|call_path| {
+        .resolve_qualified_name(func)
+        .is_some_and(|qualified_name| {
             matches!(
-                call_path.as_slice(),
+                qualified_name.segments(),
                 ["datetime", "datetime", "utcfromtimestamp"]
             )
         })
