@@ -1,6 +1,7 @@
 use ruff_diagnostics::{Diagnostic, Violation};
 use ruff_macros::{derive_message_formats, violation};
 use ruff_python_ast::{self as ast, Expr, Stmt};
+use ruff_python_semantic::Modules;
 use ruff_text_size::Ranged;
 
 use crate::checkers::ast::Checker;
@@ -40,12 +41,16 @@ pub struct DjangoExcludeWithModelForm;
 impl Violation for DjangoExcludeWithModelForm {
     #[derive_message_formats]
     fn message(&self) -> String {
-        format!("Do not use `exclude` with `ModelForm`, use `fields` instead")
+        "Do not use `exclude` with `ModelForm`, use `fields` instead".to_string()
     }
 }
 
 /// DJ006
 pub(crate) fn exclude_with_model_form(checker: &mut Checker, class_def: &ast::StmtClassDef) {
+    if !checker.semantic().seen_module(Modules::DJANGO) {
+        return;
+    }
+
     if !is_model_form(class_def, checker.semantic()) {
         return;
     }
