@@ -55,7 +55,7 @@ impl Violation for RawStringInException {
 
     #[derive_message_formats]
     fn message(&self) -> String {
-        format!("Exception must not use a string literal, assign to variable first")
+        "Exception must not use a string literal, assign to variable first".to_string()
     }
 
     fn fix_title(&self) -> Option<String> {
@@ -110,7 +110,7 @@ impl Violation for FStringInException {
 
     #[derive_message_formats]
     fn message(&self) -> String {
-        format!("Exception must not use an f-string literal, assign to variable first")
+        "Exception must not use an f-string literal, assign to variable first".to_string()
     }
 
     fn fix_title(&self) -> Option<String> {
@@ -166,7 +166,7 @@ impl Violation for DotFormatInException {
 
     #[derive_message_formats]
     fn message(&self) -> String {
-        format!("Exception must not use a `.format()` string directly, assign to variable first")
+        "Exception must not use a `.format()` string directly, assign to variable first".to_string()
     }
 
     fn fix_title(&self) -> Option<String> {
