@@ -61,19 +61,18 @@ pub struct UnnecessaryPlaceholder {
 impl AlwaysFixableViolation for UnnecessaryPlaceholder {
     #[derive_message_formats]
     fn message(&self) -> String {
-        let Self { kind } = self;
-        match kind {
-            Placeholder::Pass => format!("Unnecessary `pass` statement"),
-            Placeholder::Ellipsis => format!("Unnecessary `...` literal"),
+        match &self.kind {
+            Placeholder::Pass => "Unnecessary `pass` statement".to_string(),
+            Placeholder::Ellipsis => "Unnecessary `...` literal".to_string(),
         }
     }
 
     fn fix_title(&self) -> String {
-        let Self { kind } = self;
-        match kind {
-            Placeholder::Pass => format!("Remove unnecessary `pass`"),
-            Placeholder::Ellipsis => format!("Remove unnecessary `...`"),
-        }
+        let title = match &self.kind {
+            Placeholder::Pass => "Remove unnecessary `pass`",
+            Placeholder::Ellipsis => "Remove unnecessary `...`",
+        };
+        title.to_string()
     }
 }
 
