@@ -71,7 +71,7 @@ use crate::checkers::ast::Checker;
 ///     def __iadd__(self, other: Foo) -> Self: ...
 /// ```
 /// ## References
-/// - [`typing.Self` documentation](https://docs.python.org/3/library/typing.html#typing.Self)
+/// - [Python documentation: `typing.Self`](https://docs.python.org/3/library/typing.html#typing.Self)
 #[violation]
 pub struct NonSelfReturnType {
     class_name: String,
@@ -86,7 +86,7 @@ impl Violation for NonSelfReturnType {
             method_name,
         } = self;
         if matches!(class_name.as_str(), "__new__") {
-            format!("`__new__` methods usually return `self` at runtime")
+            "`__new__` methods usually return `self` at runtime".to_string()
         } else {
             format!("`{method_name}` methods in classes like `{class_name}` usually return `self` at runtime")
         }
