@@ -55,10 +55,9 @@ impl Violation for MultipleWithStatements {
 
     #[derive_message_formats]
     fn message(&self) -> String {
-        format!(
-            "Use a single `with` statement with multiple contexts instead of nested `with` \
-             statements"
-        )
+        "Use a single `with` statement with multiple contexts instead of nested `with` \
+            statements"
+            .to_string()
     }
 
     fn fix_title(&self) -> Option<String> {
@@ -168,7 +167,6 @@ pub(crate) fn multiple_with_statements(
             TextRange::new(with_stmt.start(), colon.end()),
         );
         if !checker
-            .indexer()
             .comment_ranges()
             .intersects(TextRange::new(with_stmt.start(), with_stmt.body[0].start()))
         {
