@@ -32,7 +32,7 @@ use ruff_macros::{derive_message_formats, violation};
 /// ## References
 /// - [Python documentation: `Path.stat`](https://docs.python.org/3/library/pathlib.html#pathlib.Path.stat)
 /// - [Python documentation: `os.path.getmtime`](https://docs.python.org/3/library/os.path.html#os.path.getmtime)
-/// - [PEP 428](https://peps.python.org/pep-0428/)
+/// - [PEP 428 – The pathlib module – object-oriented filesystem paths](https://peps.python.org/pep-0428/)
 /// - [Correspondence between `os` and `pathlib`](https://docs.python.org/3/library/pathlib.html#correspondence-to-tools-in-the-os-module)
 /// - [Why you should be using pathlib](https://treyhunner.com/2018/12/why-you-should-be-using-pathlib/)
 /// - [No really, pathlib is great](https://treyhunner.com/2019/01/no-really-pathlib-is-great/)
@@ -42,6 +42,6 @@ pub struct OsPathGetmtime;
 impl Violation for OsPathGetmtime {
     #[derive_message_formats]
     fn message(&self) -> String {
-        format!("`os.path.getmtime` should be replaced by `Path.stat().st_mtime`")
+        "`os.path.getmtime` should be replaced by `Path.stat().st_mtime`".to_string()
     }
 }
