@@ -42,7 +42,7 @@ pub struct LoggingTooFewArgs;
 impl Violation for LoggingTooFewArgs {
     #[derive_message_formats]
     fn message(&self) -> String {
-        format!("Not enough arguments for `logging` format string")
+        "Not enough arguments for `logging` format string".to_string()
     }
 }
 
@@ -79,7 +79,7 @@ pub struct LoggingTooManyArgs;
 impl Violation for LoggingTooManyArgs {
     #[derive_message_formats]
     fn message(&self) -> String {
-        format!("Too many arguments for `logging` format string")
+        "Too many arguments for `logging` format string".to_string()
     }
 }
 
@@ -115,10 +115,13 @@ pub(crate) fn logging_call(checker: &mut Checker, call: &ast::ExprCall) {
             }
         }
         Expr::Name(_) => {
-            let Some(call_path) = checker.semantic().resolve_call_path(call.func.as_ref()) else {
+            let Some(qualified_name) = checker
+                .semantic()
+                .resolve_qualified_name(call.func.as_ref())
+            else {
                 return;
             };
-            let ["logging", attribute] = call_path.as_slice() else {
+            let ["logging", attribute] = qualified_name.segments() else {
                 return;
             };
             if LoggingLevel::from_attribute(attribute).is_none() {
@@ -134,7 +137,7 @@ pub(crate) fn logging_call(checker: &mut Checker, call: &ast::ExprCall) {
         return;
     };
 
-    let Ok(summary) = CFormatSummary::try_from(value.as_str()) else {
+    let Ok(summary) = CFormatSummary::try_from(value.to_str()) else {
         return;
     };
 
