@@ -30,7 +30,7 @@ pub struct DeprecatedCElementTree;
 impl AlwaysFixableViolation for DeprecatedCElementTree {
     #[derive_message_formats]
     fn message(&self) -> String {
-        format!("`cElementTree` is deprecated, use `ElementTree`")
+        "`cElementTree` is deprecated, use `ElementTree`".to_string()
     }
 
     fn fix_title(&self) -> String {
@@ -68,7 +68,7 @@ pub(crate) fn deprecated_c_element_tree(checker: &mut Checker, stmt: &Stmt) {
             level,
             range: _,
         }) => {
-            if level.is_some_and(|level| level > 0) {
+            if *level > 0 {
                 // Ex) `import .xml.etree.cElementTree as ET`
             } else if let Some(module) = module {
                 if module == "xml.etree.cElementTree" {
