@@ -26,6 +26,7 @@ pub(crate) use single_item_membership_test::*;
 pub(crate) use slice_copy::*;
 pub(crate) use slice_to_remove_prefix_or_suffix::*;
 pub(crate) use sorted_min_max::*;
+pub(crate) use subclass_builtin::*;
 pub(crate) use type_none_comparison::*;
 pub(crate) use unnecessary_enumerate::*;
 pub(crate) use unnecessary_from_float::*;
@@ -60,6 +61,7 @@ mod single_item_membership_test;
 mod slice_copy;
 mod slice_to_remove_prefix_or_suffix;
 mod sorted_min_max;
+mod subclass_builtin;
 mod type_none_comparison;
 mod unnecessary_enumerate;
 mod unnecessary_from_float;
