@@ -18,10 +18,9 @@ use ruff_python_codegen::Stylist;
 use ruff_python_index::Indexer;
 use ruff_python_parser::ParseError;
 use ruff_python_trivia::textwrap::dedent;
-use ruff_source_file::{Locator, SourceFileBuilder};
+use ruff_source_file::SourceFileBuilder;
 use ruff_text_size::Ranged;
 
-use crate::directives;
 use crate::fix::{fix_file, FixResult};
 use crate::linter::check_path;
 use crate::message::{Emitter, EmitterContext, Message, TextEmitter};
@@ -30,6 +29,7 @@ use crate::registry::AsRule;
 use crate::settings::types::UnsafeFixes;
 use crate::settings::{flags, LinterSettings};
 use crate::source_kind::SourceKind;
+use crate::{directives, Locator};
 
 #[cfg(not(fuzzing))]
 pub(crate) fn test_resource_path(path: impl AsRef<Path>) -> std::path::PathBuf {
@@ -111,8 +111,8 @@ pub(crate) fn test_contents<'a>(
     let source_type = PySourceType::from(path);
     let parsed = ruff_python_parser::parse_unchecked_source(source_kind.source_code(), source_type);
     let locator = Locator::new(source_kind.source_code());
-    let stylist = Stylist::from_tokens(parsed.tokens(), &locator);
-    let indexer = Indexer::from_tokens(parsed.tokens(), &locator);
+    let stylist = Stylist::from_tokens(parsed.tokens(), locator.contents());
+    let indexer = Indexer::from_tokens(parsed.tokens(), locator.contents());
     let directives = directives::extract_directives(
         parsed.tokens(),
         directives::Flags::from_settings(settings),
@@ -174,8 +174,8 @@ pub(crate) fn test_contents<'a>(
             let parsed =
                 ruff_python_parser::parse_unchecked_source(transformed.source_code(), source_type);
             let locator = Locator::new(transformed.source_code());
-            let stylist = Stylist::from_tokens(parsed.tokens(), &locator);
-            let indexer = Indexer::from_tokens(parsed.tokens(), &locator);
+            let stylist = Stylist::from_tokens(parsed.tokens(), locator.contents());
+            let indexer = Indexer::from_tokens(parsed.tokens(), locator.contents());
             let directives = directives::extract_directives(
                 parsed.tokens(),
                 directives::Flags::from_settings(settings),
