@@ -16,8 +16,10 @@ pub(crate) fn derive_impl(input: DeriveInput) -> syn::Result<proc_macro2::TokenS
                 .collect::<Result<Vec<_>, _>>()?;
 
             Ok(quote! {
+                #[automatically_derived]
                 impl crate::configuration::CombinePluginOptions for #ident {
                     fn combine(self, other: Self) -> Self {
+                        #[allow(deprecated)]
                         Self {
                         #(
                             #output
