@@ -2,11 +2,12 @@ use ruff_formatter::prelude::{space, token};
 use ruff_formatter::write;
 use ruff_python_ast::StmtAssert;
 
-use crate::comments::{SourceComment, SuppressionKind};
+use crate::comments::SourceComment;
 
 use crate::expression::maybe_parenthesize_expression;
 use crate::expression::parentheses::Parenthesize;
-use crate::prelude::*;
+use crate::preview::is_join_implicit_concatenated_string_enabled;
+use crate::{has_skip_comment, prelude::*};
 
 #[derive(Default)]
 pub struct FormatStmtAssert;
@@ -29,12 +30,18 @@ impl FormatNodeRule<StmtAssert> for FormatStmtAssert {
         )?;
 
         if let Some(msg) = msg {
+            let parenthesize = if is_join_implicit_concatenated_string_enabled(f.context()) {
+                Parenthesize::IfBreaksParenthesized
+            } else {
+                Parenthesize::IfBreaks
+            };
+
             write!(
                 f,
                 [
                     token(","),
                     space(),
-                    maybe_parenthesize_expression(msg, item, Parenthesize::IfBreaks),
+                    maybe_parenthesize_expression(msg, item, parenthesize),
                 ]
             )?;
         }
@@ -47,6 +54,6 @@ impl FormatNodeRule<StmtAssert> for FormatStmtAssert {
         trailing_comments: &[SourceComment],
         context: &PyFormatContext,
     ) -> bool {
-        SuppressionKind::has_skip_comment(trailing_comments, context.source())
+        has_skip_comment(trailing_comments, context.source())
     }
 }
